@@ -17,23 +17,15 @@
  For feedback and questions about my Files and Projects please mail me,
  Alexander Matthes (Ziz) , ziz_at_mailbox.org
 */
-#define AHA_VERSION "0.4.9.0"
+#define AHA_VERSION "0.4.10.3"
 #define AHA_YEAR "2016"
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
 
-int future=0;
-int future_char=0;
-
 int getNextChar(register FILE* fp)
 {
 	int c;
-	if (future)
-	{
-		future=0;
-		return future_char;
-	}
 	if ((c = fgetc(fp)) != EOF)
 		return c;
 	fprintf(stderr,"Unknown Error in File Parsing!\n");
@@ -143,7 +135,7 @@ int main(int argc,char* args[])
 			printf("Example: \033[1maha\033[0m --help | \033[1maha\033[0m --black > aha-help.htm\n");
 			printf("         Writes this help text to the file aha-help.htm\n\n");
 			printf("Copyleft \033[1;32mAlexander Matthes\033[0m aka \033[4mZiz\033[0m "AHA_YEAR"\n");
-			printf("         \033[5;36mzizsdl@googlemail.com\033[0m\n");
+			printf("         \033[5;36mziz@mailbox.org\033[0m\n");
 			printf("         \033[5;36mhttps://github.com/theZiz/aha\033[0m\n");
 			printf("This application is subject to the \033[1;34mMPL\033[0m or \033[1;34mLGPL\033[0m.\n");
 			return 0;
@@ -251,58 +243,64 @@ int main(int argc,char* args[])
 			printf("<style type=\"text/css\">\n");
 			switch (colorshema)
 			{
-				case 1:  printf("body       {color: white; background-color: black;}\n");
-								 printf(".reset     {color: white;}\n");
-								 printf(".bg-reset  {background-color: black;}\n");
+				case 1:  printf("body         {color: white; background-color: black;}\n");
+								 printf(".reset       {color: white;}\n");
+								 printf(".bg-reset    {background-color: black;}\n");
+								 printf(".inverted    {color: black;}\n");
+								 printf(".bg-inverted {background-color: white;}\n");
 								 break;
-				case 2:  printf("body       {background-color: pink;}\n");
-								 printf(".reset     {color: black;}\n");
-								 printf(".bg-reset  {background-color: pink;}\n");
+				case 2:  printf("body         {background-color: pink;}\n");
+								 printf(".reset       {color: black;}\n");
+								 printf(".bg-reset    {background-color: pink;}\n");
+								 printf(".inverted    {color: pink;}\n");
+								 printf(".bg-inverted {background-color: black;}\n");
 								 break;
-				default: printf(".reset     {color: black;}\n");
-				         printf(".bg-reset  {background-color: white;}\n");
+				default: printf(".reset       {color: black;}\n");
+				         printf(".bg-reset    {background-color: white;}\n");
+				         printf(".inverted    {color: white;}\n");
+				         printf(".bg-inverted {background-color: black;}\n");
 			}
 			if (colorshema!=1)
 			{
 				printf(".dimgray     {color: dimgray;}\n");
-				printf(".red       {color: red;}\n");
-				printf(".green     {color: green;}\n");
-				printf(".yellow    {color: olive;}\n");
-				printf(".blue      {color: blue;}\n");
-				printf(".purple    {color: purple;}\n");
-				printf(".cyan      {color: teal;}\n");
-				printf(".white     {color: gray;}\n");
-				printf(".bg-black  {background-color: black;}\n");
-				printf(".bg-red    {background-color: red;}\n");
-				printf(".bg-green  {background-color: green;}\n");
-				printf(".bg-yellow {background-color: olive;}\n");
-				printf(".bg-blue   {background-color: blue;}\n");
-				printf(".bg-purple {background-color: purple;}\n");
-				printf(".bg-cyan   {background-color: teal;}\n");
-				printf(".bg-white  {background-color: gray;}\n");
+				printf(".red         {color: red;}\n");
+				printf(".green       {color: green;}\n");
+				printf(".yellow      {color: olive;}\n");
+				printf(".blue        {color: blue;}\n");
+				printf(".purple      {color: purple;}\n");
+				printf(".cyan        {color: teal;}\n");
+				printf(".white       {color: gray;}\n");
+				printf(".bg-black    {background-color: black;}\n");
+				printf(".bg-red      {background-color: red;}\n");
+				printf(".bg-green    {background-color: green;}\n");
+				printf(".bg-yellow   {background-color: olive;}\n");
+				printf(".bg-blue     {background-color: blue;}\n");
+				printf(".bg-purple   {background-color: purple;}\n");
+				printf(".bg-cyan     {background-color: teal;}\n");
+				printf(".bg-white    {background-color: gray;}\n");
 			}
 			else
 			{
 				printf(".dimgray     {color: dimgray;}\n");
-				printf(".red       {color: red;}\n");
-				printf(".green     {color: lime;}\n");
-				printf(".yellow    {color: yellow;}\n");
-				printf(".blue      {color: #3333FF;}\n");
-				printf(".purple    {color: fuchsia;}\n");
-				printf(".cyan      {color: aqua;}\n");
-				printf(".white     {color: white;}\n");
-				printf(".bg-black  {background-color: black;}\n");
-				printf(".bg-red    {background-color: red;}\n");
-				printf(".bg-green  {background-color: lime;}\n");
-				printf(".bg-yellow {background-color: yellow;}\n");
-				printf(".bg-blue   {background-color: #3333FF;}\n");
-				printf(".bg-purple {background-color: fuchsia;}\n");
-				printf(".bg-cyan   {background-color: aqua;}\n");
-				printf(".bg-white  {background-color: white;}\n");
+				printf(".red         {color: red;}\n");
+				printf(".green       {color: lime;}\n");
+				printf(".yellow      {color: yellow;}\n");
+				printf(".blue        {color: #3333FF;}\n");
+				printf(".purple      {color: fuchsia;}\n");
+				printf(".cyan        {color: aqua;}\n");
+				printf(".white       {color: white;}\n");
+				printf(".bg-black    {background-color: black;}\n");
+				printf(".bg-red      {background-color: red;}\n");
+				printf(".bg-green    {background-color: lime;}\n");
+				printf(".bg-yellow   {background-color: yellow;}\n");
+				printf(".bg-blue     {background-color: #3333FF;}\n");
+				printf(".bg-purple   {background-color: fuchsia;}\n");
+				printf(".bg-cyan     {background-color: aqua;}\n");
+				printf(".bg-white    {background-color: white;}\n");
 			}
-			printf(".underline {text-decoration: underline;}\n");
-			printf(".bold      {font-weight: bold;}\n");
-			printf(".blink     {text-decoration: blink;}\n");
+			printf(".underline   {text-decoration: underline;}\n");
+			printf(".bold        {font-weight: bold;}\n");
+			printf(".blink       {text-decoration: blink;}\n");
 			printf("</style>\n");
 		}
 		if (word_wrap)
@@ -399,26 +397,14 @@ int main(int argc,char* args[])
 														case 4: //Reset underline
 															ul=0;
 															break;
-															case 7: //Reset Inverted
+														case 7: //Reset Inverted
+															if (bc == -1)
+																bc = 8;
+															if (fc == -1)
+																fc = 9;
 															temp = bc;
-															if (fc == -1 || fc == 9)
-															{
-																if (colorshema!=1)
-																	bc = 0;
-																else
-																	bc = 7;
-															}
-															else
-																bc = fc;
-															if (temp == -1 || temp == 9)
-															{
-																if (colorshema!=1)
-																	fc = 7;
-																else
-																	fc = 0;
-															}
-															else
-																fc = temp;
+															bc = fc;
+															fc = temp;
 															break;
 													}
 													break;
@@ -431,27 +417,15 @@ int main(int argc,char* args[])
 												bc=momelem->digit[mompos+1];
 											break;
 							case 5: bl=1; break;
-							case 7: //TODO: Inverse
-											temp = bc;
-											if (fc == -1 || fc == 9)
-											{
-												if (colorshema!=1)
-													bc = 0;
-												else
-													bc = 7;
-											}
-											else
-												bc = fc;
-											if (temp == -1 || temp == 9)
-											{
-												if (colorshema!=1)
-													fc = 7;
-												else
-													fc = 0;
-											}
-											else
-												fc = temp;
-											break;
+							case 7:
+								if (bc == -1)
+									bc = 8;
+								if (fc == -1)
+									fc = 9;
+								temp = bc;
+								bc = fc;
+								fc = temp;
+								break;
 								}
 							}
 							momelem=momelem->next;
@@ -547,13 +521,22 @@ int main(int argc,char* args[])
 											 else
 												 printf("color:white;");
 											 break; //White
+							case	8: if (stylesheet)
+												 printf("inverted ");
+											 else if (colorshema==1)
+												 printf("color:black;");
+											 else if (colorshema==2)
+												 printf("color:pink;");
+											 else
+												 printf("color:white;");
+											 break; //Background Colour
 							case	9: if (stylesheet)
 												 printf("reset ");
 											 else if (colorshema!=1)
 												 printf("color:black;");
 											 else
 												 printf("color:white;");
-											 break; //Reset
+											 break; //Foreground Color
 						}
 						switch (bc)
 						{
@@ -609,7 +592,7 @@ int main(int argc,char* args[])
 											 else
 												 printf("background-color:white;");
 											 break; //White
-							case	9: if (stylesheet)
+							case	8: if (stylesheet)
 												 printf("bg-reset ");
 											 else if (colorshema==1)
 												 printf("background-color:black;");
@@ -617,7 +600,14 @@ int main(int argc,char* args[])
 												 printf("background-color:pink;");
 											 else
 												 printf("background-color:white;");
-											 break; //Reset
+											 break; //Background Colour
+							case	9: if (stylesheet)
+												 printf("bg-inverted ");
+											 else if (colorshema!=1)
+												 printf("background-color:black;");
+											 else
+												 printf("background-color:white;");
+											 break; //Foreground Colour
 						}
 						if (ul)
 						{
@@ -651,6 +641,14 @@ int main(int argc,char* args[])
 				while (c != 2 && c != 7) //STX and BEL end a OSC.
 					c = getNextChar(fp);
 			}
+			else
+			if ( c == '(' ) //Some VT100 ESC sequences, which should be ignored
+			{
+				//Reading (and ignoring!) one character should work for "(B"
+				//(US ASCII character set), "(A" (UK ASCII character set) and
+				//"(0" (Graphic). This whole "standard" is fucked up. Really...
+				c = getNextChar(fp);
+			}
 		}
 		else
 		if (c==13 && htop_fix)
